@@ -658,19 +658,20 @@ void testSequenceOfAny(test_TestFactory factory,
 /**
    This test tests memory management of exceptions in anys
  */
-void testAnyException(test_TestFactory factory, 
-					  CORBA_Environment *ev) {
-  test_AnyServer objref;
-  CORBA_any *inArg; 
-  test_TestException * testex;
+void
+testAnyException (test_TestFactory   factory, 
+		  CORBA_Environment *ev)
+{
+	CORBA_any          *inArg; 
+	test_TestException *testex;
 
-  inArg = CORBA_any__alloc();
-  testex = test_TestException__alloc();  
-  inArg->_type = (CORBA_TypeCode) TC_test_TestException;
-  inArg->_value = testex;
-  CORBA_any_set_release(inArg,CORBA_TRUE);
+	inArg = CORBA_any__alloc ();
+	testex = test_TestException__alloc ();  
+	inArg->_type = (CORBA_TypeCode) TC_test_TestException;
+	inArg->_value = testex;
+	CORBA_any_set_release (inArg, CORBA_TRUE);
 
-  CORBA_free(inArg);
+	CORBA_free (inArg);
 }
 
 void testTypeCode(test_TestFactory factory, 
